********************
*MID data variables*
********************

*set directory to wherever .dta file is saved
 
use "WeeksIO.dta", clear

gen float recip=0
replace recip=1 if cwhost2>1
*cwhost2>1 picks up all instances in which the target responded with a militarized action

gen float capshare1=cap_1/(cap_1 + cap_2)
gen float logcaprat=log(cap_1/cap_2)

gen float ally=.
replace ally=1 if alliance==1
replace ally=1 if alliance==2
replace ally=1 if alliance==3
replace ally=0 if alliance==4

gen float majmaj=0
replace majmaj=1 if majpow1==1 &majpow2==1
gen float majmin=0
replace majmin=1 if majpow1==1 & majpow2==0
gen float minmaj=0
replace minmaj=1 if majpow1==0 & majpow2==1

gen float revter=0
replace revter=1 if cwrevt11==1
gen float revpol=0
replace revpol=1 if cwrevt11==2
gen float revgov=0
replace revgov=1 if cwrevt11== 3
gen float revoth=0
replace revoth=1 if cwrevt11==4

replace dtrade=. if dtrade==-999
replace s1=. if s1==-9
replace s2=. if s2==-9
replace w1=. if w1==-9
replace w2=. if w2==-9

*fix contig variable
rename contig contig1
gen contig=0
replace contig=1 if contig1<6
*no missing values, so can use <

*mark bilateral dyads
gen bilateral=0
replace bilateral=1 if cwnumst1==1 & cwnumst2==1

label define regimetype1label 1 "democracy" 2 "personalist" 3 "military" 4 "single" 5 "hybrid" 6 "dynastic monarchy" 7 "non-dynastic monarchy" 8 "interregna" 9 "no info" 10 "other" 11 "interregnadem"
label values regimetype1 regimetype1label

*****************************************
*Using Eugene data, for 1816 period only*
*****************************************

*variable marking whether initiator has an actual "regime"
gen int chaosEUG=0
replace chaosEUG=1 if dem1<-11

*generate Eugene variables just for comparison

gen demdum1EUG=.
replace demdum1EUG=0 if dem1<7
replace demdum1EUG=1 if dem1>6
replace demdum1EUG=. if dem1==.

gen demdum2EUG= .
replace demdum2EUG=0 if dem2<7
replace demdum2EUG=1 if dem2>6
replace demdum2EUG=. if dem2==.

gen demdumbothEUG = demdum1EUG*demdum2EUG
*browse year ccodecow abbrev1 ccodecow2 abbrev2 cwkeynum recip cwinit cwhost1 cwhost2 dem1 polityIV polity2_1 demdum1 personal1 purepers1 hybridpers1 single1 military1 hybrid1 monarch1 other1 interregna chaosPOL threeyr w1 dem2 polityIV2 demdum2 majmaj minmaj majmin  cap_1  cap_2 capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945

gen tankerwar=0
replace tankerwar=1 if ccodecow==645 & (year>1983 & year<1988)
replace tankerwar=1 if ccodecow==630 & (year>1983 & year<1989)

gen seizure=0
replace seizure=1 if cwhiact1==15


	*1586 cases total 1946-1999
	*But drop India 1947 and Zimbabwe 1965, 1969 since no regimetype info
drop if year==1947 & abbrev1=="IND"
drop if year==1965 & abbrev1=="ZIM"
drop if year==1969 & abbrev1=="ZIM"
exit


	*2545 from 1816-1999
nmissing recip interregnadem personal1 single1 military1 hybrid1 monarch1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth polityIV w1 s1 if year>1945 & year<2000


********************************************************
******************Tables FINAL VERSION******************
********************************************************

************************************************************
*For Table 2, do "Regime Type Summary statistics.do"       *
************************************************************

*********
*Table 1*
*********
	*1816 period
tab demdum1schultz if year<2000, summarize(recip)
tabulate demdum1schultz reci if year<2000, chi2
tab demdum1 if year<2000, summarize(recip)
tabulate demdum1 recip if year<2000, chi2

	*postwar period
tab demdum1schultz if year>1945 & year<2000, summarize(recip)
tabulate demdum1schultz recip if year>1945 & year<2000, chi2
tab demdum1 if year>1945 & year<2000, summarize(recip)
tabulate demdum1 recip if year>1945 & year<2000, chi2

********************
*Table 2 for SAMPLE*
********************
tabstat polityIV if year>1945 & year<2000, statistics(mean n sem) by(regimetype1)
*with CI's
bysort regimetype1: ci polity2_1

**************************************
*Table 7: Polity score by regime type*
**************************************
tab regimetype1, summarize(polity2_1)

bysort regimetype1: ci polity2_1 if year>1945

*********
*Table 3*
*********
tab regimetype1 if year>1945 & year<2000 & noinfo1!=1, summarize(recip)
tab regimetype1 if year>1945 & year<2000 & threeyr==1, summarize(recip)
	*Iran, for curiousity: recip of .32, would only strengthen results!
	*what if take out USSR?
*tab regimetype1 if year>1945 & year<2000 & ccodecow!=365, summarize(recip)

*How many regimes DO meet threeyr rule but are not coded by Geddes?
count if year>1945 & year<2000 & threeyr==1 & regimetype1==9

*********
*Table 4*
*********
gen demdum2schultz=demdum2
gen demdumbothschultz=demdum1schultz*demdum2schultz

*fake regression to order variables correctly for tables
label var recip "Dummy Model Table 4"
logit recip single1 military1 hybrid1 other1 dynastic1 nondynastic1 interregna interregnadem personal1 w1 polityIV majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000, robust cluster(cwkeynum) 
outreg using Table4, se bdec(2) replace

	*Schultz rep 1945-1999 consolidated democracies only
label var recip "Table 4 Model 1"
logit recip demdum1 majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000, robust cluster(cwkeynum) 
outreg using Table4, se bdec(2) append
estsumm

	*full sample with Geddes: democracy is base category
label var recip "Table 4 Model 2"
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000, robust cluster(cwkeynum)
outreg using Table4, se bdec(2) append
estsumm

	*bilateral sample with Geddes: democracy is base category
label var recip "Table 4 Model 3"
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & bilateral==1, robust cluster(cwkeynum)
outreg using Table4, se bdec(2) append

	*autocracies ONLY, using personalists as base category (how different from personalists are other autocs)
label var recip "Table 4 Model 4"
logit recip polity2_1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & demdum1==0, robust cluster(cwkeynum)
outreg using Table4, se bdec(2) append

	*exclude personalists and drop major power status: does capshare predict recip?
label var recip "Table 4 Model 4"
logit recip single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & personal1==0, robust cluster(cwkeynum)
outreg using Table4, se bdec(2) append

***********
*End Table*
***********

***********************
***Robustness Checks***
***********************
	*Schultz rep
label var recip "Model 1"
logit recip demdum1schultz majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year<1985 & ww==0, robust cluster(cwkeynum) 

	*Schultz  rep 1945-1999
label var recip "Model 2"
logit recip demdum1schultz majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000, robust cluster(cwkeynum) 

	*full sample with w1 only
logit recip w1 majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000, robust cluster(cwkeynum) 

	*full sample with w1 and Geddes
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 w1 majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000, robust cluster(cwkeynum) 

	*full sample with s1 only
logit recip s1 majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000, robust cluster(cwkeynum) 

	*full sample with s1 and Geddes
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 s1 majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000, robust cluster(cwkeynum) 

	*full sample with Polity scores - but Polity correlated .79 in sample with demdum1....
cor demdum1 polity2_1 if year>1945
label var recip "Model 8"
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 polity2_1 majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000, robust cluster(cwkeynum)
outreg using Table5, se bdec(2) append

	*include monocratism from Polity dataset
label var recip "Model 8"
logit recip mono1 interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & demdum1!=. & personal1!=. & mono1>-66, robust cluster(cwkeynum)

	*do targets matter? 
label var recip "Model 9"
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 personal2 single2 military2 hybrid2 monarch2 other2 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000, robust cluster(cwkeynum)

	*controlling for energy to pick up "weak states"
label var recip "Model 11"
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 energy_1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000, robust cluster(cwkeynum)

	*"pure" personalist vs. hybrid personalist regimes
label var recip "Model 12"
logit recip interregnadem purepers1 hybridpers1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000, robust cluster(cwkeynum)

	*controlling for trade
label var recip "Model 13"
logit recip personal1 single1 military1 hybrid1 dynastic1 nondynastic1 other1 majmaj minmaj majmin capshare1 dtrade contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & chaosPOL==0 & threeyr==1 & demdum1!=. & personal1!=., robust cluster(cwkeynum)

	*politically relevant dyads only
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & pol_rel==1, robust cluster(cwkeynum)

	*drop all seizures (raids are not accounted for here)
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & cwhiact1!=15, robust cluster(cwkeynum)

	*drop all clashes (raids are not accounted for here)
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & cwhiact1!=17, robust cluster(cwkeynum)

	*What if you exclude all disputes where neither side seeks a revision? cwrevt11==0
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & cwrevt11!=0, robust cluster(cwkeynum)

	*control for target regime type
logit recip interregnadem personal1 single1 military1 hybrid1 monarch1 interregna other1 demdum2 personal2 single2 military2 monarch2 hybrid2 other2 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000, robust cluster(cwkeynum)


*********************************************
*Robustness -- dropping individual countries*
*********************************************
	*drop the Soviets -- are they driving single party coefficient?  NO! 
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & ccodecow!=365, robust cluster(cwkeynum)

	*drop the Chinese
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & ccodecow!=710, robust cluster(cwkeynum)

	*drop Chinese AND Soviets
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & ccodecow!=710 & ccodecow!=365, robust cluster(cwkeynum)

	*drop Syria
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & ccodecow!=652, robust cluster(cwkeynum)

	*drop Syria AND North Korea
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & ccodecow!=731 & ccodecow!=652, robust cluster(cwkeynum)

	*drop US, India, Israel, sep and together
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & ccodecow!=2, robust cluster(cwkeynum)
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & ccodecow!=750, robust cluster(cwkeynum)
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & ccodecow!=666, robust cluster(cwkeynum)
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & ccodecow!=2 & ccodecow!=750 & ccodecow!=666, robust cluster(cwkeynum)
	
	*drop Thailand
logit recip interregnadem personal1 single1 military1 hybrid1 dynastic1 nondynastic1 interregna other1 majmaj minmaj majmin capshare1 contig ally s_wt_glo s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000  & ccodecow!=800, robust cluster(cwkeynum)


**********************************************
*focus on results including winning coalition*
**********************************************
gen s1pers=s1*personal1
gen s1sing=s1*single1
gen s1mil=s1*military1
gen s1hyb=s1*hybrid1
gen s1monarch=s1*monarch1
gen s1interregna=s1*interregna
logit recip s1 personal1 s1pers single1 s1sing military1 s1mil hybrid1 s1hyb monarch1 s1monarch interregna s1interregna majmaj minmaj majmin capshare1 energy_1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & chaosPOL==0 & threeyr==1 & demdum1!=. & personal1!=., robust cluster(cwkeynum)
gen w1pers=w1*personal1
gen w1sing=w1*single1
gen w1mil=w1*military1
gen w1hyb=w1*hybrid1
gen w1monarch=w1*monarch
gen w1interregna=w1*interregna
logit recip w1 personal1 w1pers single1 w1sing military1 w1mil hybrid1 w1hyb monarch1 w1monarch interregna w1interregna majmaj minmaj majmin capshare1 energy_1 contig ally s_wt_glo  s_ld_1 s_ld_2 revter revgov revpol revoth if year>1945 & year<2000 & chaosPOL==0 & threeyr==1 & demdum1!=. & personal1!=. & regimetype1!=9, robust cluster(cwkeynum)


